@@ -83,18 +83,11 @@ listMarts <- function( mart = NULL, host="www.ensembl.org", path="/biomart/marts
     request = NULL
     if(is.null(mart)){
         
-        ## adding option to force use of specificed host with ensembl
-        #redirect <- ifelse(!ensemblRedirect && grepl(x = host, pattern = "ensembl.org"), 
-        #                   "&redirect=no",
-        #                   "")
-        
         host <- .cleanHostURL(host)
         if(archive) {
-            warning("The archive = TRUE argument is now deprecated.\nUse listEnsemblArchives() to find the URL to directly query an Ensembl archive.")
-            request = paste0(host, ":", port, path, "?type=registry_archive&requestid=biomaRt")
+            stop("The archive = TRUE argument is now defunct.\nUse listEnsemblArchives() to find the URL to directly query an Ensembl archive.")
         } 
         else {
-            #request = paste0(host, ":", port, path, "?type=registry&requestid=biomaRt", redirect)	
             request = paste0(host, ":", port, path, "?type=registry&requestid=biomaRt")
         }
     }
@@ -111,10 +104,18 @@ listMarts <- function( mart = NULL, host="www.ensembl.org", path="/biomart/marts
     
     ## check this looks like the MartRegistry XML, otherwise throw an error
     if(!grepl(x = registry, pattern = "^\n*<MartRegistry>")) {
-        stop('Unexpected format to the list of available marts.\n',
-             'Please check the following URL manually, ',
-             'and try ?listMarts for advice.\n',
-             request)
+        
+        if(grepl(x = registry, pattern = "status.ensembl.org")) {
+            stop("Your query has been redirected to http://status.ensembl.org ",
+                 "indicating this Ensembl service is currently unavailable",
+                 "\nLook at ?useEnsembl for details on how to try a mirror site.",
+                 call. = FALSE)
+        } else {
+            stop('Unexpected format to the list of available marts.\n',
+                 'Please check the following URL manually, ',
+                'and try ?listMarts for advice.\n',
+                request)
+        }
     }
     registry = xmlTreeParse(registry, asText=TRUE)
     registry = registry$doc$children[[1]]
@@ -162,12 +163,7 @@ listMarts <- function( mart = NULL, host="www.ensembl.org", path="/biomart/marts
         return(marts)
     }
     else{
-        if(archive){
-            ret = data.frame(biomart = as.character(marts$database),version = as.character(marts$version), stringsAsFactors=FALSE)
-        }
-        else{
-            ret = data.frame(biomart = as.character(marts$biomart),version = as.character(marts$version), stringsAsFactors=FALSE)
-        }
+        ret = data.frame(biomart = as.character(marts$biomart),version = as.character(marts$version), stringsAsFactors=FALSE)
         return(ret)
     } 
 }
@@ -216,7 +212,7 @@ useMart <- function(biomart, dataset, host = "www.ensembl.org", path = "/biomart
     
     if(is.na(marts$path[mindex]) || is.na(marts$vschema[mindex]) || is.na(marts$host[mindex]) || is.na(marts$port[mindex]) || is.na(marts$path[mindex])) stop("The selected biomart databases is not available due to error in the BioMart central registry, please report so the BioMart registry file can be fixed.")
     if(marts$path[mindex]=="") marts$path[mindex]="/biomart/martservice" #temporary to catch bugs in registry
-    if(archive) biomart = marts$biomart[mindex]
+    #if(archive) biomart = marts$biomart[mindex]
     if(!missing(version)) biomart = marts$biomart[mindex]
     biomart = sub(" ","%20",biomart, fixed = TRUE, useBytes = TRUE)
     
@@ -229,9 +225,10 @@ useMart <- function(biomart, dataset, host = "www.ensembl.org", path = "/biomart
                 biomart = biomart,
                 vschema = marts$vschema[mindex], 
                 host = paste0(host, ":", 
-                              port, 
-                              marts$path[mindex]), 
-                archive = archive)
+                              #marts$port[mindex],
+                              port,
+                              marts$path[mindex]))#, 
+               # archive = archive)
     
     if(length(grep("archive",martHost(mart)) > 0)){
         
@@ -396,10 +393,11 @@ checkDataset <- function(dataset, mart) {
 
 ## Select a BioMart dataset             
 useDataset <- function(dataset, mart, verbose = FALSE){
-    if(missing(mart) || class(mart)!="Mart") stop("No valid Mart object given, specify a Mart object with the attribute mart")
+    if(missing(mart) || class(mart)!="Mart") 
+        stop("No valid Mart object given, specify a Mart object with the attribute mart")
     
     if(missing(dataset)) {
-        stop("No dataset given.  Please use the dataset argument to specify which dataset you want to use. Correct dataset names can be obtained with the listDatasets function.")
+        stop("No dataset given.  Please use the dataset argument to specify which dataset you want to use. Correct dataset names can be obtained with the listDatasets() function.")
     } else {
         dataset <- checkDataset(dataset = dataset, mart = mart)
     }
@@ -578,7 +576,7 @@ getBM <- function(attributes, filters = "", values = "", mart, curl = NULL, chec
             print(postRes)
         }
         if(!(is.character(postRes) && (length(postRes)==1L)))
-            stop("The query to the BioMart webservice returned an invalid result: biomaRt expected a character string of length 1. Please report this to the mailing list.")
+            stop("The query to the BioMart webservice returned an invalid result: biomaRt expected a character string of length 1. \nPlease report this on the support site at http://support.bioconductor.org")
         
         if(gsub("\n", "", postRes, fixed = TRUE, useBytes = TRUE) == "") { # meaning an empty result
             
@@ -600,7 +598,7 @@ getBM <- function(attributes, filters = "", values = "", mart, curl = NULL, chec
             
             if(!(is(result, "data.frame") && (ncol(result)==length(attributes)))) {
                 print(head(result))
-                stop("The query to the BioMart webservice returned an invalid result: the number of columns in the result table does not equal the number of attributes in the query. Please report this to the mailing list.")
+                stop("The query to the BioMart webservice returned an invalid result: the number of columns in the result table does not equal the number of attributes in the query. \nPlease report this on the support site at http://support.bioconductor.org")
             }
         }
         
@@ -619,6 +617,11 @@ getLDS <- function(attributes, filters = "", values = "", mart, attributesL, fil
     
     martCheck(mart)
     martCheck(martL)
+    
+    if(martHost(mart) != martHost(martL)) {
+        stop('Both datasets must be located on the same host.')
+    }
+    
     invalid = !(attributes %in% listAttributes(mart, what="name"))
     if(any(invalid))
         stop(paste("Invalid attribute(s):", paste(attributes[invalid], collapse=", "),
@@ -764,7 +767,7 @@ getLDS <- function(attributes, filters = "", values = "", mart, attributesL, fil
         res_attributes <- c(attributes,attributesL)
         if(!(is(result, "data.frame") && (ncol(result)==length(res_attributes)))) {
             print(head(result))
-            stop("The query to the BioMart webservice returned an invalid result: the number of columns in the result table does not equal the number of attributes in the query. Please report this to the mailing list.")
+            stop("The query to the BioMart webservice returned an invalid result: the number of columns in the result table does not equal the number of attributes in the query. \nPlease report this on the support site at http://support.bioconductor.org")
         } 
         if(!bmHeader){  #assumes order of results same as order of attibutes in input
             colnames(result) = res_attributes
